==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/fa-IR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'این کاربر می تواند وارد شود
',
    'activated_disabled_help_text' => 'شما نمی توانید وضعیت فعال سازی را برای حساب خود ویرایش کنید.
',
    'assets_user'       => 'دارایی ها محول شده به :',
    'bulk_update_warn'	=> 'شما در حال خواندن مشخصات خواص کاربر user_count هستید. لطفا توجه داشته باشید که نمیتوانید ویژگیهای کاربر خود را با استفاده از این فرم تغییر دهید و باید به صورت جداگانه به کاربر خود ویرایش کنید.',
    'bulk_update_help'	=> 'این فرم به شما امکان می دهد چندین بار در یک بار به روز کنید. فقط فیلمی را که باید تغییر دهید را پر کنید. هر فیلدی که خالی باقی می ماند بدون تغییر باقی خواهد ماند.',
    'current_assets'    => 'دارایی های اکنون  برای این کاربر بیرون کشیده شد',
    'clone'             => 'کلون کاربر',
    'contact_user'      => 'تماس با:',
    'edit'              => 'ویرایش کاربر',
    'filetype_info'     => 'پسوند های مجاز:png, gif, jpg, jpeg, doc, docx, pdf, txt, zip,Rar',
    'history_user'      => 'تاریخچه برای:',
    'info'				=> 'اطلاعات',
    'restore_user'		=> 'برای بازسازی آنها اینجا کلیک کنید.',
    'last_login'        => 'آخرین ورود',
    'ldap_config_text'  => 'تنظشیمات تاییدیه LDPA در فولدر app/config در فایلی به نام idap.php وجود دارد.مکان مشخص شده برای تمامی کاربران وارد شده تنظیم میشود.شما نیاز دارید که حداقل یه مکان را اضافه کرده باشید تا بتوانید از این ویژگی استفاده کنید.',
    'print_assigned'    => 'چاپ همه موارد واگذار شده',
    'email_assigned'    => 'لیست ایمیل همه اختصاص داده شده
',
    'user_notified'     => 'لیستی از موارد اختصاص داده شده فعلی به کاربر ایمیل شده است.
',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'برنامه چک شد برای:',
    'send_email_help'   => 'شما باید یک آدرس ایمیل برای این کاربر ارائه دهید تا اطلاعات کاربری خود را ارسال کند. ارسال اعتبار نامه ایمیل فقط با ایجاد کاربر امکان پذیر است. رمزهای عبور در یک هش یک طرفه ذخیره می شوند و پس از ذخیره نمی توان آنها را بازیابی کرد.
',
    'view_user'         => 'نمایش کاربر :',
    'usercsv'           => 'فایل CSV',
    'two_factor_admin_optin_help' => 'تنظیمات مدیریت فعلی شما اجازه اجرای مجدد احراز هویت دو عامل را می دهد.',
    'two_factor_enrolled' => 'دستگاه 2FA ثبت شده است',
    'two_factor_active'   => '2FA فعال',
    'user_deactivated'  => 'کاربر نمی تواند وارد شود
',
    'user_activated'  => 'کاربر می تواند وارد شود
',
    'activation_status_warning' => 'وضعیت فعال سازی را تغییر ندهید
',
    'group_memberships_helpblock' => 'فقط سوپرادمین ها می توانند عضویت های گروه را ویرایش کنند.
',
    'superadmin_permission_warning' => 'فقط superadmin ها می توانند به کاربر اجازه دسترسی superadmin را بدهند.
',
    'admin_permission_warning' => 'فقط کاربران با حقوق سرپرست یا بیشتر می توانند به کاربر اجازه دسترسی سرپرست بدهند.
',
    'remove_group_memberships' => 'حذف عضویت در گروه
',
    'warning_deletion_information' => 'شما در شرف بررسی همه موارد از کاربر(های) :count فهرست شده در زیر هستید. نام های فوق ادمین با رنگ قرمز مشخص شده اند.
',
    'update_user_assets_status' => 'همه دارایی های این کاربران را به این وضعیت به روز کنید
',
    'checkin_user_properties' => 'تمام ویژگی های مرتبط با این کاربران را بررسی کنید
',
    'remote_label'   => 'این یک کاربر از راه دور است
',
    'remote'   => 'از دور',
    'remote_help' => 'اگر نیاز به فیلتر کردن توسط کاربران راه دوری که هرگز یا به ندرت به مکان های فیزیکی شما نمی آیند، می تواند مفید باشد.
',
    'not_remote_label' => 'این یک کاربر راه دور نیست
',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/fa-IR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'این کاربر می تواند وارد شود
',
    'activated_disabled_help_text' => 'شما نمی توانید وضعیت فعال سازی را برای حساب خود ویرایش کنید.
',
    'assets_user'       => 'دارایی ها محول شده به :',
    'bulk_update_warn'	=> 'شما در حال خواندن مشخصات خواص کاربر user_count هستید. لطفا توجه داشته باشید که نمیتوانید ویژگیهای کاربر خود را با استفاده از این فرم تغییر دهید و باید به صورت جداگانه به کاربر خود ویرایش کنید.',
    'bulk_update_help'	=> 'این فرم به شما امکان می دهد چندین بار در یک بار به روز کنید. فقط فیلمی را که باید تغییر دهید را پر کنید. هر فیلدی که خالی باقی می ماند بدون تغییر باقی خواهد ماند.',
    'current_assets'    => 'دارایی های اکنون  برای این کاربر بیرون کشیده شد',
    'clone'             => 'کلون کاربر',
    'contact_user'      => 'تماس با:',
    'edit'              => 'ویرایش کاربر',
    'filetype_info'     => 'پسوند های مجاز:png, gif, jpg, jpeg, doc, docx, pdf, txt, zip,Rar',
    'history_user'      => 'تاریخچه برای:',
    'info'				=> 'اطلاعات',
    'restore_user'		=> 'برای بازسازی آنها اینجا کلیک کنید.',
    'last_login'        => 'آخرین ورود',
    'ldap_config_text'  => 'تنظشیمات تاییدیه LDPA در فولدر app/config در فایلی به نام idap.php وجود دارد.مکان مشخص شده برای تمامی کاربران وارد شده تنظیم میشود.شما نیاز دارید که حداقل یه مکان را اضافه کرده باشید تا بتوانید از این ویژگی استفاده کنید.',
    'print_assigned'    => 'چاپ همه موارد واگذار شده',
    'email_assigned'    => 'لیست ایمیل همه اختصاص داده شده
',
    'user_notified'     => 'لیستی از موارد اختصاص داده شده فعلی به کاربر ایمیل شده است.
',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'برنامه چک شد برای:',
    'view_user'         => 'نمایش کاربر :',
    'usercsv'           => 'فایل CSV',
    'two_factor_admin_optin_help' => 'تنظیمات مدیریت فعلی شما اجازه اجرای مجدد احراز هویت دو عامل را می دهد.',
    'two_factor_enrolled' => 'دستگاه 2FA ثبت شده است',
    'two_factor_active'   => '2FA فعال',
    'user_deactivated'  => 'کاربر نمی تواند وارد شود
',
    'user_activated'  => 'کاربر می تواند وارد شود
',
    'activation_status_warning' => 'وضعیت فعال سازی را تغییر ندهید
',
    'group_memberships_helpblock' => 'فقط سوپرادمین ها می توانند عضویت های گروه را ویرایش کنند.
',
    'superadmin_permission_warning' => 'فقط superadmin ها می توانند به کاربر اجازه دسترسی superadmin را بدهند.
',
    'admin_permission_warning' => 'فقط کاربران با حقوق سرپرست یا بیشتر می توانند به کاربر اجازه دسترسی سرپرست بدهند.
',
    'remove_group_memberships' => 'حذف عضویت در گروه
',
    'warning_deletion_information' => 'شما در شرف بررسی همه موارد از کاربر(های) :count فهرست شده در زیر هستید. نام های فوق ادمین با رنگ قرمز مشخص شده اند.
',
    'update_user_assets_status' => 'همه دارایی های این کاربران را به این وضعیت به روز کنید
',
    'checkin_user_properties' => 'تمام ویژگی های مرتبط با این کاربران را بررسی کنید
',
    'remote_label'   => 'این یک کاربر از راه دور است
',
    'remote'   => 'از دور',
    'remote_help' => 'اگر نیاز به فیلتر کردن توسط کاربران راه دوری که هرگز یا به ندرت به مکان های فیزیکی شما نمی آیند، می تواند مفید باشد.
',
    'not_remote_label' => 'این یک کاربر راه دور نیست
',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
    'department_manager' => 'Department Manager',
];
